﻿using System.IO;

namespace TestProject
{
    /// <summary>
    /// 파일 시스템 데이타 제공자
    /// </summary>
    public static class FileSystemDataProvider
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 논리 드라이브 배열 구하기 - GetLogicalDriveArray()

        /// <summary>
        /// 논리 드라이브 배열 구하기
        /// </summary>
        /// <returns>논리 드라이브 배열</returns>
        public static string[] GetLogicalDriveArray()
        {
            return Directory.GetLogicalDrives();
        }

        #endregion
        #region 하위 폴더 배열 구하기 - GetSubfolders(folderPath)

        /// <summary>
        /// 하위 폴더 배열 구하기
        /// </summary>
        /// <param name="folderPath">폴더 경로</param>
        /// <returns>하위 폴더 배열</returns>
        public static string[] GetSubfolderArray(string folderPath)
        {
            return Directory.GetDirectories(folderPath);
        }

        #endregion
        #region 하위 파일 배열 구하기 - GetSubfiles(folderPath)

        /// <summary>
        /// 하위 파일 배열 구하기
        /// </summary>
        /// <param name="folderPath">폴더 경로</param>
        /// <returns>하위 파일 배열</returns>
        public static string[] GetSubfileArray(string folderPath)
        {
            return Directory.GetFiles(folderPath);
        }

        #endregion
        #region 폴더명 구하기 - GetFolderName(folderPath)

        /// <summary>
        /// 폴더명 구하기
        /// </summary>
        /// <param name="folderPath">폴더 경로</param>
        /// <returns>폴더명</returns>
        public static string GetFolderName(string folderPath)
        {
            return new DirectoryInfo(folderPath).Name;
        }

        #endregion
        #region 파일명 구하기 - GetFileName(filePath)

        /// <summary>
        /// 파일명 구하기
        /// </summary>
        /// <param name="filePath">파일 경로</param>
        /// <returns>파일명</returns>
        public static string GetFileName(string filePath)
        {
            return new FileInfo(filePath).Name;
        }

        #endregion
        #region 파일 크기 구하기 - GetFileSize(filePath)

        /// <summary>
        /// 파일 크기 구하기
        /// </summary>
        /// <param name="filePath">파일 경로</param>
        /// <returns>파일 크기</returns>
        public static long GetFileSize(string filePath)
        {
            return new FileInfo(filePath).Length;
        }

        #endregion
    }
}