﻿using System.Windows;

using DevExpress.Utils;
using DevExpress.Xpf.Grid;
using DevExpress.Xpf.Grid.TreeList;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            PrepareDriveNodes();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 트리 리스트 뷰 노드 확장시 처리하기 - treeListView_NodeExpanding(sender, e)

        /// <summary>
        /// 트리 리스트 뷰 노드 확장시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeListView_NodeExpanding(object sender, TreeListNodeAllowEventArgs e)
        {
            TreeListNode node = e.Node;

            if(node.Tag == null || (bool)node.Tag == false)
            {
                PrepareChildNodes(node);

                node.Tag = true;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 드라이브 노드들 준비하기 - PrepareDriveNodes()

        /// <summary>
        /// 드라이브 노드들 준비하기
        /// </summary>
        public void PrepareDriveNodes()
        {
            this.gridControl.BeginDataUpdate();

            try
            {
                string[] driveArray = FileSystemDataProvider.GetLogicalDriveArray();

                foreach(string drive in driveArray)
                {
                    TreeListNode node = new TreeListNode() { Content = new FileSystemItem(drive, "Drive", "<Drive>", drive) };

                    this.treeListView.Nodes.Add(node);

                    node.IsExpandButtonVisible = DefaultBoolean.True;
                }
            }
            catch
            {
            }

            this.gridControl.EndDataUpdate();
        }

        #endregion
        #region 자식 파일/폴더 소유 여부 조사하기 - HasChildFileOrFolder(folderPath)

        /// <summary>
        ///  자식 파일/폴더 소유 여부 조사하기
        /// </summary>
        /// <param name="folderPath">폴더 경로</param>
        /// <returns>자식 파일/폴더 소유 여부</returns>
        private bool HasChildFileOrFolder(string folderPath)
        {
            string[] filePathArray = FileSystemDataProvider.GetSubfileArray(folderPath);

            if(filePathArray.Length > 0)
            {
                return true;
            }

            string[] folderPathArray = FileSystemDataProvider.GetSubfolderArray(folderPath);

            if(folderPathArray.Length > 0)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 자식 폴더 노드 준비하기 - PrepareChildFolderNodes(parentNode)

        /// <summary>
        /// 자식 폴더 노드 준비하기
        /// </summary>
        /// <param name="parentNode">부모 노드</param>
        private void PrepareChildFolderNodes(TreeListNode parentNode)
        {
            FileSystemItem parentFileSystemItem = parentNode.Content as FileSystemItem;

            if(parentFileSystemItem == null)
            {
                return;
            }

            try
            {
                string[] subfolderArray = FileSystemDataProvider.GetSubfolderArray(parentFileSystemItem.ItemFullName);

                foreach(string subfolder in subfolderArray)
                {
                    try
                    {
                        TreeListNode childNode = new TreeListNode() { Content = new FileSystemItem(FileSystemDataProvider.GetFolderName(subfolder), "Folder", "<Folder>", subfolder) };

                        parentNode.Nodes.Add(childNode);

                        childNode.IsExpandButtonVisible = HasChildFileOrFolder(subfolder) ? DefaultBoolean.True : DefaultBoolean.False;
                    }
                    catch
                    {
                    }
                }
            }
            catch
            {
            }
        }

        #endregion
        #region 자식 파일 노드 준비하기 - PrepareChildFileNodes(parentNode)

        /// <summary>
        /// 자식 파일 노드 준비하기
        /// </summary>
        /// <param name="parentNode">부모 노드</param>
        private void PrepareChildFileNodes(TreeListNode parentNode)
        {
            FileSystemItem parentFileSystemItem = parentNode.Content as FileSystemItem;

            if(parentFileSystemItem == null)
            {
                return;
            }

            TreeListNode childNode;

            try
            {
                string[] filePathArray = FileSystemDataProvider.GetSubfileArray(parentFileSystemItem.ItemFullName);

                foreach(string filePath in filePathArray)
                {
                    childNode = new TreeListNode() { Content = new FileSystemItem(FileSystemDataProvider.GetFileName(filePath), "File", FileSystemDataProvider.GetFileSize(filePath).ToString(), filePath) };

                    childNode.IsExpandButtonVisible = DefaultBoolean.False;

                    parentNode.Nodes.Add(childNode);
                }
            }
            catch
            {
            }
        }

        #endregion
        #region 자식 노드들 준비하기 - PrepareChildNodes(node)

        /// <summary>
        /// 자식 노드들 준비하기
        /// </summary>
        /// <param name="node">노드</param>
        private void PrepareChildNodes(TreeListNode node)
        {
            this.gridControl.BeginDataUpdate();

            PrepareChildFolderNodes(node);

            PrepareChildFileNodes(node);

            this.gridControl.EndDataUpdate();
        }

        #endregion
    }
}